@@ -20,6 +20,7 @@
  *  http://www.r-project.org/Licenses/
  */
 
+#include <string.h>
 #include "foreign.h"
 #include "file-handle.h"
 #include "pfm.h"
@@ -568,9 +569,10 @@ read_SPSS_SAVE(const char *filename)
     }
     UNPROTECT(1);
 
+    SEXP cpsym = install("codepage");
     free_dictionary(dict);
     setAttrib(ans, R_NamesSymbol, ans_names);
-    setAttrib(ans, install("codepage"), ScalarInteger(inf.encoding));
+    setAttrib(ans, cpsym, ScalarInteger(inf.encoding));
     UNPROTECT(2);
     return ans;
 }
